Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1069)

Unified Diff: chrome/browser/icon_loader.h

Issue 1110313002: [chrome/browser] Replace MessageLoopProxy usage with ThreadTaskRunnerHandle (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixed Review Comments Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/icon_loader.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/icon_loader.h
diff --git a/chrome/browser/icon_loader.h b/chrome/browser/icon_loader.h
index 0e48a45fe33a3bf798aaeff14393ac01f0e81a4a..52df888dac209283a3821dbfccfa1f0ec785dca9 100644
--- a/chrome/browser/icon_loader.h
+++ b/chrome/browser/icon_loader.h
@@ -13,7 +13,7 @@
#include "base/files/file_path.h"
#include "base/memory/ref_counted.h"
#include "base/memory/scoped_ptr.h"
-#include "base/message_loop/message_loop_proxy.h"
+#include "base/single_thread_task_runner.h"
#include "content/public/browser/browser_thread.h"
#include "ui/gfx/image/image.h"
@@ -87,8 +87,8 @@ class IconLoader : public base::RefCountedThreadSafe<IconLoader> {
void NotifyDelegate();
- // The message loop object of the thread in which we notify the delegate.
- scoped_refptr<base::MessageLoopProxy> target_message_loop_;
+ // The task runner object of the thread in which we notify the delegate.
+ scoped_refptr<base::SingleThreadTaskRunner> target_task_runner_;
base::FilePath file_path_;
« no previous file with comments | « no previous file | chrome/browser/icon_loader.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698